/*
 *   This is the header file which defines the interface 
 *  which each of the httpcapture plugins must implement.
 *
 *   Each plugin is a seperate, self-contained, shared library
 *  containing an object derived from this class.
 *
 */

#ifndef _PLUGIN_H
#define _PLUGIN_H 1

#include <string>


#define MAXDATALEN 8192


/*
 *  A unique connection - when the application starts it will
 * keep track of complete connections, and at the point the
 * connection terminates an object of this type containing all
 * the details will be passed to each plugin.
 *
 *  This is the object that each plugin will be dealing with when it
 * is called to handle packet capture.
 *
 */
typedef struct 
{
    /*
     * Sequence number, source address, and destination address.
     */
    long seq, src, dst;

    /*
     * Source port, destination port, and capture length.
     */
    int sport, dport, count;

    
    /*
     * The captured data itself.
     */
    char buf[MAXDATALEN];

} connection;





/*
 *  The plugin interface for httpcapture, each plugin must derive from this
 * class, and implement each method.
 *
 *  The important one is 'processPackets' the rest are purely diagnostic,
 * and don't need to be changed often.
 *
 *  This code is derived from that I wrote and used upon GNUMP3d.
 *  
 */
class IPlugin
{
 public:
  /**
   * This function returns a constant string describing
   * the author of the plugin.
   */
  virtual std::string getAuthor() = 0;

  /**
   * Return a description of this plugin - this will be displayed
   * by 'httpcapture --list'
   */
  virtual std::string getDescription() = 0;

  /**
   * Let the plugin do it's thang.
   */
  virtual void processPacket( const char *src, const char *dst, connection *currentConnection ) = 0;

};


/**
 * This method is needed to allow the plugin to be created.
 * simpley code this to create an instance of your plugin
 * class.
 */
extern "C" IPlugin *factory();

#endif /* _PLUGIN_H */
